@@ -28,6 +28,7 @@ from fsspec.asyn import (
     AsyncFileSystem,
     get_loop,
     sync_wrapper,
+    get_running_loop,
 )
 from fsspec.spec import AbstractBufferedFile
 from fsspec.utils import infer_storage_options, tokenize
@@ -327,6 +328,8 @@ class AzureBlobFileSystem(AsyncFileSystem):
         Client secret to use when authenticating using an AD Service Principal client/secret.
     tenant_id: str
         Tenant ID to use when authenticating using an AD Service Principal client/secret.
+    anon: bool
+        Explicit support for anonymous login
     default_fill_cache: bool = True
         Whether to use cache filling with opoen by default
     default_cache_type: string ('bytes')
@@ -357,6 +360,11 @@ class AzureBlobFileSystem(AsyncFileSystem):
         ...    client_id=CLIENT_ID, client_secret=CLIENT_SECRET)
     >>> abfs.ls('')
 
+    Authentication with environment based identity which can be  EnvironmentCredential, ManagedIdentityCredential,
+    SharedTokenCache(Windows only), AzureCLI identity
+    >>> abfs = AzureBlobFileSystem(account_name="XXXX", tenant_id=TENANT_ID)
+
+
     **  Read files as: **
         -------------
         ddf = dd.read_csv('abfs://container_name/folder/*.csv', storage_options={
@@ -380,6 +388,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         client_id: str = None,
         client_secret: str = None,
         tenant_id: str = None,
+        anon: bool = False,
         location_mode: str = "primary",
         loop=None,
         asynchronous: bool = False,
@@ -405,6 +414,7 @@ class AzureBlobFileSystem(AsyncFileSystem):
         self.client_id = client_id or os.getenv("AZURE_STORAGE_CLIENT_ID")
         self.client_secret = client_secret or os.getenv("AZURE_STORAGE_CLIENT_SECRET")
         self.tenant_id = tenant_id or os.getenv("AZURE_STORAGE_TENANT_ID")
+        self.anon = anon
         self.location_mode = location_mode
         self.credential = credential
         self.request_session = request_session
@@ -416,12 +426,17 @@ class AzureBlobFileSystem(AsyncFileSystem):
             self.credential is None
             and self.account_key is None
             and self.sas_token is None
-            and self.client_id is not None
         ):
-            (
-                self.credential,
-                self.sync_credential,
-            ) = self._get_credential_from_service_principal()
+            if self.client_id is not None:
+                (
+                    self.credential,
+                    self.sync_credential,
+                ) = self._get_credential_from_service_principal()
+            else:
+                (
+                    self.credential,
+                    self.sync_credential,
+                ) = self._get_default_credential()
         else:
             self.sync_credential = None
         self.do_connect()
@@ -483,9 +498,26 @@ class AzureBlobFileSystem(AsyncFileSystem):
 
         return (async_credential, sync_credential)
 
+    def _get_default_credential(self):
+        """
+        Use azure identity default credential resolver method. This is useful both for local development
+        (eg. to use VS Code token cache) and on Azure by using managed identity.
+        https://docs.microsoft.com/en-us/python/api/azure-identity/azure.identity.defaultazurecredential
+
+        Returns
+        -------
+        Tuple of (Async Credential, Sync Credential).
+        """
+        from azure.identity import DefaultAzureCredential
+        from azure.identity.aio import (
+            DefaultAzureCredential as AIODefaultAzureCredential,
+        )
+
+        return (AIODefaultAzureCredential(), DefaultAzureCredential())
+
     def do_connect(self):
         """Connect to the BlobServiceClient, using user-specified connection details.
-        Tries credentials first, then connection string and finally account key
+        Tries credentials first, then connection string and finally account key.
 
         Raises
         ------
@@ -518,10 +550,12 @@ class AzureBlobFileSystem(AsyncFileSystem):
                         credential=None,
                         _location_mode=self.location_mode,
                     )
-                else:
+                elif self.anon is True:
                     self.service_client = AIOBlobServiceClient(
                         account_url=self.account_url
                     )
+                else:
+                    raise ValueError()
             else:
                 raise ValueError(
                     "Must provide either a connection_string or account_name with credentials!!"
@@ -1682,7 +1716,7 @@ class AzureBlobFile(AbstractBufferedFile):
             # the thread. If not, create the fsspec loop
             # and set it.  This is to handle issues with
             # Async Credentials from the Azure SDK
-            loop = asyncio.get_running_loop()
+            loop = get_running_loop()
 
         except RuntimeError:
             loop = get_loop()
